@@ -139,7 +139,7 @@ class DumpResultSqlite(DumpResult):
 
 		for key in update_keys:
 			# get previous saved copy:
-			old_key, lines, parents  = self.get_obj_from_db(self.targets[key])
+			old_key, lines, parents = self.get_obj_from_db(key)
 
 			# update that copy
 			self.update_in_db(
